#
# spec file for package quagga
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%if 0%{?suse_version} > 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif
%bcond_with    tcp_zebra
%bcond_without irdp
%bcond_with    isis
%bcond_with    isis_topology
%bcond_without pcre
%if %{defined _rundir}
%define         quagga_statedir %{_rundir}/%{name}
%else
%define         quagga_statedir %{_localstatedir}/run/%{name}
%endif
Name:           quagga
Version:        1.1.1
Release:        lp152.4.6
Summary:        Routing Software for BGP, OSPF and RIP
License:        LGPL-2.1+
Group:          Productivity/Networking/Routing
Url:            http://www.quagga.net
Source:         http://download.savannah.gnu.org/releases/quagga/%{name}-%{version}.tar.gz
Source1:        %{name}-SUSE.tar.bz2
Source2:        %{name}.pam
Source3:        http://download.savannah.gnu.org/releases/quagga/%{name}-%{version}.tar.gz.asc
# downloaded from: http://download.savannah.gnu.org/releases/quagga/pgp-54CD2E60.asc
# new download from:
# http://www.nongnu.org/quagga/quagga.net.pgp.asc
Source4:        %{name}.keyring
Source5:        %{name}-tmpfs.conf
Source6:        sysconfig.%{name}
Source7:        %{name}.logrotate
Patch1:         %{name}-add-ospf6_main-return-value.patch
Patch2:         %{name}-add-table_test-return-value.patch
Patch3:         0001-systemd-change-the-WantedBy-target.patch
Patch4:         quagga-CVE-2017-16227-bgpd-Fix-AS_PATH-size-calculation.patch
Patch5:         Quagga-2018-0543-bgpd.bsc1079798.patch
Patch6:         Quagga-2018-1114-bgpd.bsc1079799.patch
Patch7:         Quagga-2018-1550-bgpd-bsc1079800.patch
Patch8:         Quagga-2018-1975-bdpd.bsc1079801.patch
BuildRequires:  autoconf >= 2.6
BuildRequires:  automake >= 1.6
BuildRequires:  libtool
BuildRequires:  net-snmp-devel
BuildRequires:  pam-devel
BuildRequires:  readline-devel
BuildRequires:  xz
Requires(post): %fillup_prereq
Requires(post): %{install_info_prereq}
# pwdutils for useradd and groupadd
Requires(pre):  pwdutils
Recommends:     logrotate
Provides:       zebra = %{version}
Obsoletes:      zebra < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with pcre}
BuildRequires:  pcre-devel
%endif
%if 0%{?suse_version} > 1220
BuildRequires:  makeinfo
%endif
%if %{with systemd}
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
Requires(post): %insserv_prereq
%endif

%description
Quagga is a routing software suite, providing implementations of
OSPFv2, OSPFv3, RIP v1 and v2, RIPv3 and BGPv4. Quagga is a fork of
GNU Zebra.

%package -n libospf0
Summary:        Quagga's implementation of the OSPF protocol
Group:          System/Libraries

%description -n libospf0
This library contains part of the OSPFv2 implementation of Quagga.

%package -n libospfapiclient0
Summary:        API for Quagga's OSPFv2 implementation
Group:          System/Libraries

%description -n libospfapiclient0
This library contains part of the OSPFv2 implementation of Quagga.

%package -n libzebra1
Summary:        Quagga utility library
Group:          System/Libraries

%description -n libzebra1
This library contains various utility functions to Quagga, such as
data types, buffers and socket handling.

%package -n libfpm_pb0
Summary:        Quagga fpm protobuf library
Group:          System/Libraries

%description -n libfpm_pb0
This library contains forwarding plane manager protobuf definitions
for Quagga.

%package -n libquagga_pb0
Summary:        Quagga quagga protobuf library
Group:          System/Libraries

%description -n libquagga_pb0
This library contains protobuf memory management for Quagga.

%package devel
Summary:        Development files for quagga, a routing software for BGP, OSPF, RIP
Group:          Development/Libraries/C and C++
Requires:       libfpm_pb0 = %{version}
Requires:       libospf0 = %{version}
Requires:       libospfapiclient0 = %{version}
Requires:       libquagga_pb0 = %{version}
Requires:       libzebra1 = %{version}

%description devel
Quagga is a routing software suite, providing implementations of
OSPFv2, OSPFv3, RIP v1 and v2, RIPv3 and BGPv4. Quagga is a fork of
GNU Zebra.

This subpackage contains the headers for the Quagga libraries.

%prep
%setup -q -a 1
%patch1 -p 1
%patch2 -p 1
%patch3 -p 1
%patch4 -p 1
%patch5 -p 1
%patch6 -p 1
%patch7 -p 1
%patch8 -p 1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure --disable-static --with-pic \
    --enable-vtysh \
    --enable-rtadv \
    --enable-snmp \
    --enable-ipv6 \
    --with-libpam \
    --enable-netlink \
    %if %{with isis}
    --enable-isisd \
    %endif
    %if %{with isis_topology}
    --enable-isis-topology \
    %endif
    %if %{with tcp_zebra}
    --enable-tcp-zebra \
    %endif
    %if %{with irdp}
    --enable-irdp \
    %endif
    %if %{with pcre}
    --enable-pcreposix \
    %endif
    --sysconfdir=%{_sysconfdir}/quagga \
    --localstatedir=%{quagga_statedir} \
    --enable-multipath=0
make %{?_smp_mflags}

%install
rm -r doc/quagga.info
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
install -d %{buildroot}%{_sysconfdir}/{init.d,quagga,pam.d,logrotate.d}
%if %{with systemd}
install -d %{buildroot}%{_unitdir}
install -p -m 0644 redhat/zebra.service %{buildroot}%{_unitdir}/zebra.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rczebra
install -p -m 0644 redhat/isisd.service %{buildroot}%{_unitdir}/isisd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcisisd
install -p -m 0644 redhat/ripd.service %{buildroot}%{_unitdir}/ripd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcripd
install -p -m 0644 redhat/ospfd.service %{buildroot}%{_unitdir}/ospfd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcospfd
install -p -m 0644 redhat/bgpd.service %{buildroot}%{_unitdir}/bgpd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcbgpd
install -p -m 0644 redhat/ospf6d.service %{buildroot}%{_unitdir}/ospf6d.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcospf6d
install -p -m 0644 redhat/ripngd.service %{buildroot}%{_unitdir}/ripngd.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcripngd
install -d -m 0755 %{buildroot}/%{_tmpfilesdir}
install -p -m 0644 %{SOURCE5} %{buildroot}/%{_tmpfilesdir}/quagga.conf
sed -e "s|@quagga_statedir@|%{quagga_statedir}|g" -i \
                             %{buildroot}/%{_tmpfilesdir}/quagga.conf
%else
install -m 0755 SUSE/* %{buildroot}%{_sysconfdir}/init.d/
ln -sf %{_sysconfdir}/init.d/zebra  %{buildroot}%{_sbindir}/rczebra
ln -sf %{_sysconfdir}/init.d/bgpd   %{buildroot}%{_sbindir}/rcbgpd
ln -sf %{_sysconfdir}/init.d/ospf6d %{buildroot}%{_sbindir}/rcospf6d
ln -sf %{_sysconfdir}/init.d/ospfd  %{buildroot}%{_sbindir}/rcospfd
ln -sf %{_sysconfdir}/init.d/ripngd %{buildroot}%{_sbindir}/rcripngd
ln -sf %{_sysconfdir}/init.d/ripd   %{buildroot}%{_sbindir}/rcripd
%endif
install -d -m 0755 %{buildroot}%{_fillupdir}/
install -m 0644 %{SOURCE6} %{buildroot}%{_fillupdir}/sysconfig.%{name}
install -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/quagga
install -d -m 0750 %{buildroot}%{_localstatedir}/log/quagga
install -d -m 0751 %{buildroot}%{quagga_statedir}
install -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/logrotate.d/quagga
rm -f %{buildroot}%{_sysconfdir}/quagga/*.sample*
cat > %{buildroot}%{_sysconfdir}/quagga/zebra.conf << __EOF__
!hostname quagga

!password quagga
!enable password quagga

log file %{_localstatedir}/log/quagga/zebra.log
__EOF__
cat > %{buildroot}%{_sysconfdir}/quagga/vtysh.conf << __EOF__
! vtysh is using PAM authentication allowing root to use it.
__EOF__

%pre
getent group quagga >/dev/null || %{_sbindir}/groupadd -r quagga || :
getent passwd quagga >/dev/null || \
	%{_sbindir}/useradd -r -g quagga -s %{_bindir}/false \
                  -c "Quagga routing daemon" \
                  -d %{quagga_statedir} quagga || :
%if %{with systemd}
%service_add_pre zebra.service isisd.service ripd.service ospfd.service bgpd.service ospf6d.service ripngd.service
%endif

%post
%if %{with systemd}
# Use %%tmpfiles_create when Leap 43.0 is oldest in support scope
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/%{name}.conf || :
%service_add_post zebra.service isisd.service ripd.service ospfd.service bgpd.service ospf6d.service ripngd.service
%fillup_only
%else
%fillup_and_insserv
test -d %{quagga_statedir} || mkdir -m 0751 -p %{quagga_statedir}
%endif
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%if %{with systemd}
%service_del_preun zebra.service isisd.service ripd.service ospfd.service bgpd.service ospf6d.service ripngd.service
%else
%stop_on_removal zebra bgpd ospf6d ospfd ripd ripngd
%endif

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}
%if %{with systemd}
%service_del_postun zebra.service isisd.service ripd.service ospfd.service bgpd.service ospf6d.service ripngd.service
%else
%restart_on_update zebra bgpd ospf6d ospfd ripd ripngd
%insserv_cleanup
%endif

%post   -n libospf0 -p /sbin/ldconfig
%postun -n libospf0 -p /sbin/ldconfig
%post   -n libospfapiclient0 -p /sbin/ldconfig
%postun -n libospfapiclient0 -p /sbin/ldconfig
%post   -n libzebra1 -p /sbin/ldconfig
%postun -n libzebra1 -p /sbin/ldconfig
%post   -n libfpm_pb0 -p /sbin/ldconfig
%postun -n libfpm_pb0 -p /sbin/ldconfig
%post   -n libquagga_pb0 -p /sbin/ldconfig
%postun -n libquagga_pb0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc */*.sample* AUTHORS COPYING* ChangeLog NEWS README REPORTING-BUGS SERVICES TODO
%{_sbindir}/*
%dir %attr(750,quagga,quagga) %{_sysconfdir}/quagga/
%config(noreplace) %attr(640,quagga,quagga) %{_sysconfdir}/%{name}/*.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/*
%{_fillupdir}/sysconfig.quagga
%if %{with systemd}
%{_unitdir}/*.service
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/quagga.conf
%else
%config %{_sysconfdir}/init.d/*
%endif
%config (noreplace)%{_sysconfdir}/pam.d/*
%{_bindir}/*
%dir %attr(-,quagga,quagga) %{_localstatedir}/log/quagga
%dir %attr(-,quagga,quagga) %ghost %{quagga_statedir}
%{_infodir}/quagga.info*
%{_mandir}/man?/*

%files -n libospf0
%defattr(-,root,root)
%{_libdir}/libospf.so.*

%files -n libospfapiclient0
%defattr(-,root,root)
%{_libdir}/libospfapiclient.so.*

%files -n libzebra1
%defattr(-,root,root)
%{_libdir}/libzebra.so.*

%files -n libfpm_pb0
%defattr(-,root,root)
%{_libdir}/libfpm_pb.so.*

%files -n libquagga_pb0
%defattr(-,root,root)
%{_libdir}/libquagga_pb.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%dir %{_includedir}/%{name}/ospfd
%{_includedir}/%{name}/ospfd/*.h
%dir %{_includedir}/%{name}/ospfapi
%{_includedir}/%{name}/ospfapi/*.h

%changelog
* Fri Feb  9 2018 mt@suse.de
- Applied security fix for bgpd DoS via specially crafted BGP
  UPDATE messages  (CVE-2017-16227,bsc#1065641)
  [+ quagga-CVE-2017-16227-bgpd-Fix-AS_PATH-size-calculation.patch]
- Applied security fix for bgpd bounds check issue via attribute
  length (CVE-2018-5378,Quagga-2018-0543,bsc#1079798)
  [+ Quagga-2018-0543-bgpd.bsc1079798.patch]
- Applied security fix for bgpd double free when processing UPDATE
  message (CVE-2018-5379,Quagga-2018-1114,bsc#1079799)
  [+ Quagga-2018-1114-bgpd.bsc1079799.patch]
- Applied security fix for bgpd code-to-string conversion tables
  overrun (CVE-2018-5380,Quagga-2018-1550,bsc#1079800)
  [+ Quagga-2018-1550-bgpd-bsc1079800.patch]
- Applied security fix for bgpd infinite loop on certain invalid
  OPEN messages (CVE-2018-5381,Quagga-2018-1975,bsc#1079801)
  [+ Quagga-2018-1975-bdpd.bsc1079801.patch]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Apr 11 2017 mt@suse.de
- Disabled passwords in default zebra.conf config file, causing
  to disable vty telnet interface by default. The vty interface
  is available via "vtysh" utility using pam authentication to
  permit management access for root without password (bsc#1021669).
- Changed owner of /etc/quagga to quagga:quagga to permit to manage
  quagga via vty interface.
* Mon Apr  3 2017 tchvatal@suse.com
- Remove FIXME's added by spec-cleaner by using proper phases for the
  prereq deps
- Remove code checking for the proc mounting (build scripts do that
  for us anyway) + remove the commented out autoconf
- Use content of %%tmpfiles_create macro rather than 2 lines of checks
- Use version in zebra provides/obsoletes to avoid rpmlint warning
* Thu Mar 30 2017 mt@suse.de
- Update to quagga-1.1.1, a security and bug fix release (fate#323168):
  See http://mirror.easyname.at/nongnu/quagga/quagga-1.1.1.changelog.txt
  for complete changelog, a digest of the changes:
  - Telnet 'vty' interface DoS fix due to unbounded memory
    allocation (CVE-2017-5495,bsc#1021669)
  - revert opsf6d: Update router-LSA when nbr's interface-ID changes
  See http://mirror.easyname.at/nongnu/quagga/quagga-1.0.20161017.changelog.txt
  for complete changelog, a digest of the changes:
  - isisd: Fix size of malloc
  - isisd: check for the existance of the correct list
  - ospf6d: fix off-by-one on display of spf reasons
  - ospf6d: don't access nexthops out of bounds
  - bgpd: fix off-by-one in attribute flags handling
  - zebra: stack overrun in IPv6 RA receive code (CVE-2016-1245)
  - bgpd: Fix buffer overflow error in bgp_dump_routes_func
- Added libfpm_pb0 and libquagga_pb0 shared library sub-packages,
  adjusted libzebra0 sub-package name to libzebra1.
- Use tmpfiles_create RPM macro to create quagga rundir and adjust
  tmpfiles config to contain proper rundir at install time.
- Removed obsolete patches:
  quagga-CVE-2016-1245-stack-overrun-in-IPv6-RA-receive.patch
  quagga-CVE-2016-4049-fix-buf-ovflow-bgp-dump-routes.patch
  quagga-autoconf-detect-AM_SILENT_RULES.patch
- Do not enable zebra's tcp interface (port 2600) to use default
  unix socket for communication between the daemons (fate#323170).
- Added quagga.log and create and su statemets to logrotate config,
  changed default zebra log file name from quagga.log to zebra.log.
- Cleaned up the spec file using spec-cleaner.
* Sat Oct 22 2016 jengelh@inai.de
- Implement shared library policy
- Check for user/group before adding them to the system
- Trim description
* Tue Oct 18 2016 mt@suse.de
- Add quagga-CVE-2016-1245-stack-overrun-in-IPv6-RA-receive.patch:
  Fix for a zebra stack overrun in IPv6 RA receive code.
  (CVE-2016-1245, bsc#1005258)
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Wed May  4 2016 pwieczorkiewicz@suse.com
- Add quagga-CVE-2016-4049-fix-buf-ovflow-bgp-dump-routes.patch
  Fix for a buffer overflow error in bgp_dump_routes_func.
  (CVE-2016-4049, bsc#977012)
* Thu Apr  7 2016 meissner@suse.com
- replace quagga.keyring with the newer upstream keyring.
* Fri Apr  1 2016 pwieczorkiewicz@suse.com
- Add the %%{_rundir} macro handling to spec in order to distinguish
  /run/ vs /var/run distro versions.
* Fri Apr  1 2016 pwieczorkiewicz@suse.com
- Add quagga-autoconf-detect-AM_SILENT_RULES.patch:
  Fix autoconf issue of missing AM_SILENT_RULES macro.
- Add build requirement for xz
* Thu Mar 31 2016 pwieczorkiewicz@suse.com
- Disallow unprivileged users to enter config directory /etc/quagga
  (group: quagga, mode: 750) and read configuration files installed
  there (group: quagga, mode: 640). (boo#770619)
- Add sysconfig.quagga:
  Fillup template for /etc/sysconfig/quagga
- Update to version 1.0.20160315:
  See http://savannah.spinellicreations.com//quagga/quagga-1.0.20160315.changelog.txt
    Remove double read of stream
- Update to version 1.0.20160309:
  See http://savannah.spinellicreations.com//quagga/quagga-1.0.20160309.changelog.txt
    Add code to extract.pl.in to prevent further cli function
    overwrites
    Fixed if_add_update possible null dereference
    Fix _netlink_route_debug message
    Check prefix length from zebra is sensible
    Fix privilege dropping to use system defined groups
    Additional centos 6 -enable-werror fixes
    Fix code to use srandom/random
    Removal of 'show ip mroute'
  * : add/cleanup initialisers, missing includes, VRF ID in the
    API message header, assorted warning
    call if_init()/if_terminate() from vrf_init()/vrf_terminate()
    fix "babeld: Remove babeld from Quagga" (336724d)
    fix in_addr initialisers and more initialisers (for BSD)
    fix signedness mix-ups
    use an ifindex_t type, defined in lib/if.h, for ifindex values
    use long long to print time_t
    use void * for printing pointers
    babeld: Remove babeld from Quagga
    bgpd: add back old forms of 'show <afi> <safi>' for compatibility
    add "show ip bgp dampening" command tree
    add nexthop length to AF macro
    add some peer_lock/unlock debug code
    add support for timer commands with peer-group syntax
    allow using rtt in route-map's set metric
    bgp_scan shouldn't queue up route_nodes with no routes
    for processing
    check capability falls on right multiple of size,
    where possible.
    check rtt later after the real peer is known
    cleanup vty bgp_node_afi/safi utils
    compile fix for clearing-completion FSM fix, using
    workqueue helper.
    configured suppress value cannot be less than the reuse
    value in bgp dampening
    crash from not NULLing freed pointers
    display of configured dampening parameters
    do not allow a timers connect of 0
    drop machineparse / random "show" improvements
    enable "bgp log-neighbor-changes" by default
    encap: add attribute handling, add encap SAFI (RFC5512),
    extend extcommunity handling, encap show commands
    fix: bgp_btoa to compile,
    crash reported by NetDEF CI,
    ecommunity_token initialiser,
    graceful restart capability minsize,
    memory leak in bgpd/bgp_route.c,
    Null pointer dereference in bgp_info_mpath_update,
    race in clearing completion,
    small memory leak in str2prefix_rd,
    SNMP write support
    'struct peer' memory leaks
    useless call in bgpd/bgp_mplsvpn.c
    using of two pointers for struct thread_master *
    VU#270232, VPNv4 NLRI parser memcpys to stack on
    unchecked length (bsc#970952, CVE-2016-2342)
    general MP/SAFI improvements
    handle AS4 and EOI route distinguishers
    if route-map does not exist DENY for redistribute
    statements
    ignore stale entry candidates during bestpath selection.
    implicit updates in BGP may require a withdrawal from
    zebra RIB
    improve cleanup in bgp_delete()
    memory cleanups for valgrind, plus debug changes
    hook up bgp ENCAP and VPNv6 CLI node
    lower BGP's default keepalive/holdtime to 3s/9s
    lower the default 'timers connect' in BGP to 10 seconds
    make bgp_info_cmp and multiple-path decision logic more
    regular and robust to paths that do not have su_remote
    info
    make bgp_nlri_parse_encap conform with other nlri_parse
    funcs
    make _vpnv4 static handling SAFI-agnostic
    modify maxpaths cli's to use MULTIPATH_NUM for range
    only use routes from Established peers for best path
    selection
    OPEN parse errors should send OPEN_ERR and UNSPECIFIC
    subcode.
    peer_uptime overflows after 1 year
    fix zAPI parsing
    refactor route-map objects modifying integer values
    regularise BGP NLRI sanity checks a bit
    regularise bgp_update_receive, add missing notifies and
    checks
    remove the double-pass parsing of NLRIs
    'set comm-list delete' stops as soon as it hits a
    community-list entry with a deny
    speed up "no-hit" withdraws for routeservers
    tests - add null pointer protection to fix bgp test
    failures
    update dump to allow Extended Time Format
    update rtt on soft clear
    VPNv6 show commands
    warn user that bgp is setting maximum-paths larger than
    MULTIPATH_NUM
    wire up VPNv6 protocol processing
    fix struct/pointer sizeof mixups
    fixup afi_t to be an enum and cleanup zebra.h
    remove 'struct fifo' from lib/zebra.h
    refactor FILTER_X in zebra.h
    bgp:  reorg cleanup to align process and bgp instance
    init/destroy
    build: add --enable-werror
    ARM compilation warning fix
    determine CFLAGS more intelligently
    enable vtysh and pimd as part of default build
    list actual release procedure
    make libraries self-reliant
    remove the old PIC/PIE patch, let libtool sort it out
    rework how MULTIPATH_NUM is delivered to build
    distro:  fix redhat/quagga.spec.in
    distro:  redhat/rpm: remove with_ipv6, package pimd binary,
    remove pam stack
    redhat,CentOS: update to support CentOS/RHEL/Fedora,
    upstart/init/systemd
    doc: add AFI/SAFI show commands to manual
    add 'OSPF Fundamentals' section to OSPF docs
    distribute a modern version of texinfo.tex with the docs
    older versions of texinfo seem to be sensitive to location
    of unmacro
    update bgpd docs, inc. on decision process, and with a
    section on MED.
    fixup of history handling
    fix alignment assumptions on non-RT_ROUNDUP platforms.
    gdb: Add a directory of files with gdb macros
    git: add (generated) cscope files to .gitignore
    HACKING: Change format to MarkDown, fix spelling mistakes
    rename to HACKING.md in prep for conversion to MarkDown
    isisd: add a debug mode that traces LSP construction
    add a slight delay to lsp_regenerate_schedule
    add new adjacency to LSP neighbor list
    add support to import routes from other protocols
    allow to adjust lsp-mtu
    always print adj->sysid (clang 3.6 warning)
    annotate some function arguments with const
    assorted fixes (unused variables, static)
    Attached-bit in LSP header
    don't corrupt memory for long hostnames
    don't use POSIX reserved y1/yn names
    do remove ipv6 routes from Zebra
    drop packet received on multiple interfaces due to
    the time gap in binding socket to an interface
    fix: assertion in LSP refresh timer calculation
    a typo in a log message
    crash on processing own p2p hello
    IPv6 mask application
    LSPs not being regenerated after adjacency change
    minor & vs. && mix-up
    misleading wording in log
    size_t confusions
    handle lsp confusion (ISO/IEC 10589:2002 7.3.16.2)
    initialize circuit to match area is_type
    make send_lsp more robust
    provide more detailed log for failed address removal
    purge on correct level
    remove superfluous checks after XMALLOC etc.
    remove unused process_is_hello()
    show interface's ipv6 addreses
    lib:  memory cleanups for valgrind, plus debug changes
    add: CMD_RANGE_STR macro to command.h
    facility to log all CLI commands
    function to get precise remaining time of timer thread
    getgrouplist() for Solaris
    SAFI_ENCAP type, safi2str prefix utility
    "show commandtree" CLI command
    zlog_hexdump() for debugging
    allow caller to provide prefix storage in sockunion2hostprefix
    reduce strcmp in CLI hot paths
    fix optional arguments with description interactions
    constify sockunion api
    don't have log functions change errno
    fix: bookkeeping for libreadline malloc()s
    duplicate variable name in smux.c and vty.c
    Free Pointer dereference in lib/filter.c
    POSIX capabilities on SunOS platforms
    "reduce strcmp in CLI" fallout
    "sockunion: add hash function" for BSD
    vrf_bitmap leak in zclient_free()
    hide internal prefix list structures
    make prefix2str simpler to use, and use it in zclient
    make sockunion2str safer to use
    memory reporting fails over 2GB
    move the interface list into "struct vrf"
    display more info if cap_set_proc fails.
    don't use CAP_NET_BROADCAST
    remove unused 'show memory XXX' functionality
    silence type range warning in macro
    straighten out ORF prefix list support
    stream: fix stream sanity checks
    treat realloc of null pointer as alloc Now use zalloc
    rather than alloc with null. Fixes issue seen in
    bgp check tests.
    use const consistently for zserv path
    vrf: enable / disable a VRF
    vty: add separate output fd support to VTYs
    add vty_stdio()
    add vty_stdio at-close hook
    don't clear output buffer on input EOF
    put stdin in raw mode for vty
    reduce unneccessary C extension usage
    support multiple VRFs by using linux netns
    add trivial work_queue_is_scheduled helper
    wrong #define used for IPV6_MINHOPCOUNT
    zclient:  can overflow (struct interface) hw_addr if
    zebra is evil
    consolidate error reporting for zclient_read_header
    add "vrf_id" into the "struct interface"
    move "struct vrf" to be a lib module
    unify link layer type and hardware address handling
    configure an interface in non-default VRF
    ospf6d: fix for fast OSPF convergence
    fix pointer arithmetic warning
    fix uninitialized warning in SNMP
    oi->cost is uint32, not short
    use existing union, avoid strict-aliasing
    ospfd:  add missing unlock for ospf_interface_address_delete()
    extend 'ip ospf area' to take address argument + rationalise
    ospf enable
    fast OSPF convergence
    fix bug in 94266fa822ba, nbr_self rebuild didn't add
    valid nbr_self
    fix for 'no' + 'debug command' does not disable
    'debug command'
    fix unused warning in ospf_write
    impl. per interface 'ip ospf area' command
    lower the default OSPF spf timers to '0 50 5000'
    make ospf_passive_interface_update calls friendly to
    static analysis
    move route_unlock_node() in ospf_ase_incremental_update()
    ospf_ase.c, external_lsa locking fixes.
    ospf_ls_upd_send() add missing unlock.
    ospf_nbr_nbma_set()/ospf_snmp_vl_add() add unlock
    PointToPoint neighbors are identified by router ID
    remove another odd flooding hack in opaque LSA code
    remove HAVE_OPAQUE_LSA and HAVE_OSPF_TE
    remove the blocking of opaque LSAs origination and
    flooding 'optimisation'
    self nbrs needs to be rebuilt when router ID changes.
    split up network interface enable a bit, for per-interface
    area cmd
    trap on state change seems to send incorrect value for
    ospfNbrState
    use route_node_lookup() instaed of route_node_get()
    pimd: add ability to set DR Priority for an interface
    add knowledge of different packet types
    add support for configuring multicast static routes
    assert when no route to source from a new igmp join
    cast ioctl values when printing them
    cast to sockaddr_in to sockaddr
    change ioctl call failure from vty_out to zlog_warn
    cleanup interface startup
    cleanup zebra debugs to be protected by debug commands
    create ability to modify hell and hold timers per interface
    do not display some default values as part of a show run
    ensure new generation_id is different from previous
    fix first DR Election, leaked fd, out of tree build,
    size_t zlog_err format string warning
    limit pim hello log messages
    mask unused zclient_broken()
    notice when we receive a packet type we can't handle yet
    stop DR election on every hello
    use IPPROTO_IP (not SOL_IP) for IP_PKTINFO
    'show debugging' collision
    ripngd: add ECMP support
    allow to enable/disable the ECMP feature
    sockopt:   add support for querying tcp round-trip-time
    sockunion: add accessors for sockunion address
    add hash function
    solaris: create ioctl_solaris.h
    drop duplicate __EXTENSION__ define
    more warnings fixed
    no ROUNDUP
    tests:   add CLI dummy command-exec tool
    add more AS4 capability tests + little fixes for
    couple of GR test cases.
    add testcli reference in/out & do DejaGNU
    vrf: add a runtime check before playing with netns
    vtysh: add missing show thread/work-queues commands
    adjust bad_cli_stomps in extract.pl.in to reflect
    fixes & fix build
    allow display of individual daemons configs
    allow --with-libpam to build with --enable-werror
    don't use '\0' as NULL
    drop unused variables & RETSIGTYPE
    fix Quagga.conf file read in.
    fix the fix for babeld removal
    when the config file is close to the boundry of
    size of buffer vtysh hangs.
    hook up bgp ENCAP and VPNv6 CLI node
    fixup of history handling
    reduce unneccessary C extension usage
    support multiple VRFs by using linux netns
    configure an interface in non-default VRF
    zebra: fix struct/pointer sizeof mixups
    add "vrf_id" into the "struct interface"
    move "struct vrf" to be a lib module
    unify link layer type and hardware address handling
    configure an interface in non-default VRF
    add hooks upon enabling / disabling a VRF
    additional redistribute related logging
    atomic FIB updates
    clean up misc_null pragmas, RTADV define
    configure static routes in any VRF
    don't print uninitialized string
    fix: addr sent in ZEBRA_IPV6_NEXTHOP_LOOKUP
    build with rtadv disabled
    change of distance on ipv6 route creating
    duplicate routes
    leaked sockets in rtadv.c
    NetBSD interface stats printf
    non usage of VRF_DEFAULT
    route deletion on *BSD
    rtadv detection, check for non-glibc linux
    VRF code for *BSD
    implement per-route mtu handling
    let FIB stand for its respective VRF
    let the route-map rule "match interface" work
    for VRFs
    the netlink sockets work per VRF
    lookup the address in all VRFs when set the
    route-map rule "set src"
    maintain RTADV and router-id per VRF
    make RTF_LLINFO optional to fix FreeBSD
    make ZEBRA_FLAG_CHANGED internal status
    remove HAVE_IPV6 from rib.h and zebra_rib.c
    remove metric from kernel
    rib->nexthop_num is double incremented
    show interfaces in a specified VRF or all VRFs
    show routes in a specified VRF or all VRFs
    silence zebra_serv_un unused warning
    simplify redistribution code
    support FIB override routes
    use link scope for interface routes
    use prefix2str for logging where possible
    use SA_SIZE for RT_ROUNDUP on FreeBSD
    use prefix2str and unify show ip/ipv6 route code
    wire up "debug zebra packet detail"
* Sat Oct 17 2015 mrueckert@suse.de
- run systemd-tmpfiles in %%post to get the directory set up.
* Sat Mar 21 2015 p.drouand@gmail.com
- Fix build for openSUSE 13.1/SLE12
* Sat Mar 14 2015 p.drouand@gmail.com
- Update to version 0.99.24.1
  * zebra: don't print uninitialized string (3b02fe8)
    This crept in as part of the MRIB improvements and I missed the compiler
    warning between other noise.  Unfortunately, printing an uninitialised
    variable can in fact make zebra crash, so this is not trivial.
- Use systemd for openSUSE > 12.3
- Add patch from Fedora
  * 0001-systemd-change-the-WantedBy-target.patch
* Wed Jul 30 2014 sfalken@opensuse.org
- Update to 0.99.23
  See http://savannah.spinellicreations.com//quagga/quagga-0.99.23.changelog.txt
  minor fixes:
    bgpd: Fix condition allowas-in in rsclient code
    support TTL-security with iBGP, factor out TTL setting
    factor out eBGP multihop check
    fix fast external fallover behavior
    increase TCP socket buffer size
    fix O_NONBLOCK on outgoing
    send notify in OpenSent when stopping manually
    display multipath status in "show ip bgp"
    track correct originator-id in reflected routes
    add 'bgp bestpath as-path multipath-relax'
    fix crash when allowas-in is done on inactive peer
  efficient NLRI packing for AFs != ipv4-unicast
  don't compare next-hop to router-id
  use ATTR_FLAG_BIT() for BGP_ATTR_ values
  fix some DEFUN definitions
  bgpd-set-v4-nexthop-for-v6-peering.patch
  support NEXTHOP_IPV4_IFINDEX in bgp import check
  honor PEER_FLAG_DISABLE_CONNECTED_CHECK on bgp_scan
  write NOTIFY non-blockingly
  prevent double address delete on shutdown
  stricter packet handling in OpenSent
  fix lost passwords of grouped neighbors
  * : nuke ^L (page feed)
    isisd: ignore the unrecognized TLVs
    ripd: fix "show ip rip status" documentation
  avoid the zero interface metric
  correctly redistribute ifindex routes (BZ#664)
    zebra: raise the privileges before calling socket()
    Change the mechanism for comparing route ID's.
    fix some DEFUN definitions
    apply syntactic sugar to rib_dump()
    set metric for directly connected routes via netlink to 0
    log routes w/o gateway in rib_delete_ipv4
    match gateway when deleting NEXTHOP_IPV4_IFINDEX routes
    make rib_dump() compatible with IPv6 RIB
    apply route-maps for interface routes
    fix recursive-routes via ifindex routes
    implement NEXTHOP_FLAG_ONLINK
    handle blackholes encountered in recursive resolution
    rework recursive route resolution
    improve interface shutdown behaviour
    don't change connected state from zebra/interface.c
    add ZEBRA_IFC_QUEUED to keep track of kernel state
  warn if advertising connected with _REAL unset
  consolidate connected_implicit_withdraw
  clear ZEBRA_IFC_CONFIGURED on "no ipv6 addr"
  make if_subnet_delete a bit more strict
  process information about new addresses (BZ#486)`
  support NEXTHOP_IPV4_IFINDEX in bgp import check
  improve display of NEXTHOP_IPV4_IFINDEX in show ip route
  don't printf to stdout on ZEBRA_IPV6_NEXTHOP_LOOKU
  use SO_RCVBUFFORCE for netlink socket
    ospfd: add debug messages for router lsa-generation
  For an ABR, ensure the right LSID is MaxAge'd
  clarify indentation and comments in ospf_lsa_maxage_delete
  fix a reference counting issue introduced by commit 4de8bf0011
  check the LS-Ack's recentness instead of only comparing the #seq
  don't allow to set network type on loopback interfaces
  run DR election prior to LSA regeneration
  ospfd/ospf_vty.c: use keyword cmd style
  fix some DEFUN definitions
  fixup log message in ospf_zebra_delete
  refactor some common defines
  protect vs. VU#229804 (malformed Router-LSA)
  CVE-2013-2236, stack overrun in apiserver
  fix flooding procedure
  make ospf_maxage_lsa_remover actually yield
  restore nexthop IP for p2p interfaces
  fix LSA initialization for build without opaque LSA
    lib: use heap to manage timers
    remove unused thread_master_debug function
    lib/command.c: rewrite command matching/parsing
    fix possible off-by-one in stream_put_prefix()
    fix for dynamically grown hashes
    fix backtraces broken by 837d16c...
    unconditionally include stddef.h
    register vtysh socket in server socket vector (BZ#754)
    ospf6d: fix refcounting in ospf6_asbr_lsa_remove
    add "auto-cost reference-bandwidth" command
    compute interface cost from its bandwidth
    solve segfaults with ospf6d on FreeBSD
    Merge volatile/cumulus_ospf6d
    fix interface_down() stopping hellos
    clear lsa->refresh before clearing LSAs
    handle missing link local address more gracefully
    improve ordered shutdown
    clear DR info on interface_down
    set cmsg size correctly
    don't run DR election early on "ipv6 ospf6 priority"
    fix integrated config
    add SPF logs, statistics, and display of SPF parameters
    add 'log-adjacency-changes [detail]'
    don't send LSAck on an interface if we've flooded the LSU out that i/f
    handle Prefix and Router Options bits correctly
    add LSA payload to show summary output
    increment dbdesc seqnum on SeqNumberMismatch/BadLsReq event
    don't change SeqNum on initial DbDesc message
    handle seqnum wrapping
    add overload support
    fix linkdown handling
    correct nexthop through directly connected networks
    don't suppress empty router LSA
    turn off expensive debugging
    convert LSDB to use route_node, improve performance
    fix neighbor state machine (faster lsdb sync, RFC compliance)
    add p2p interface support
    fix various bugs in installing and flooding LSAs
    add more details to show ipv6 ospf6 data
    enable the commands to support detailed debugging of LSAs.
    remove older version of LSA from neigbor retx list before prematurely aging it.
    schedule SPF to run on events rather than directly on each event.
    refactor some common defines
    security: Fix some typos and potential NULL-deref
    tests: Add tests for timers
    add a test program for lib/command.c
    DejaGNU libzebra bgpd
    add DejaGNU framework
    vtysh: don't append superflous spaces (BZ#750)
  fix false lib path matching in extract.pl.in
    doc: Modernize INSTALL.quagga.txt.
    update TODO for ospf6d work & bgp multipath
    add OSPFv3 homenet to TODO
    hash: dynamically grow hash table
  force size to be a power of 2
    guile: remove
  build issues:
    lib: remove redundant and incorrect sys/fcntl.h include
    vtysh: fix build against readline 6.3
    tests: fix build & disable testcommands
    don't build tests unless make check is run
    fix Makefile.am so it works with BSD make
    make --disable-bgpd kill bgpd tests too
    build: remove now-useless --{en, dis}able-tests
  improve backtrace support/detection
  reference libcap from libzebra (BZ#393,626)
  fix minimal mixup in gitinfo suffix
  Update supported versions.
  update quagga.spec.in
    isisd: use bug-report information from autoconf
    ospf6d: use bug-report information from autoconf
    doc: fix makeinfo errors and one warning
* Wed Jul 30 2014 sfalken@opensuse.org
- Updated to 0.99.23
  Changed /var/run to /run in .spec file in order to fix rpmlint check failure in Factory
  Added:
  quagga-0.99.23.tar.xz
  quagga-0.99.23.tar.asc
  Deleted:
  quagga-0.99.22.1.tar.gz
  quagga-0.99.22.1.tar.asc
* Wed Jul 17 2013 meissner@suse.com
- fixed source url, added tar.asc and keyring url (unchecked)
* Wed Jul 17 2013 boyang@suse.com
- Add return value for table_test.c.
* Fri Apr 19 2013 boyang@suse.com
- Update to 0.99.22.1
  major regressions:
    ospfd: restore nexthop IP for p2p interfaces
  minor fixes:
    bgpd: fix lost passwords of grouped neighbors
    lib/vty: register vtysh socket in server socket vector (BZ#754)
    ospfd: fix LSA initialization for build without opaque LSA
    ripd: correctly redistribute ifindex routes (BZ#664)
  build issues:
    build: fix minimal mixup in gitinfo suffix
    build: reference libcap from libzebra (BZ#393,626)
    build: update quagga.spec.in
    doc: fix makeinfo errors and one warning
    tests: make --disable-bgpd kill bgpd tests too
    vtysh: fix false lib path matching in extract.pl.in
* Wed Sep 12 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Thu Aug  9 2012 mrueckert@suse.de
- Update to 0.99.21
  There are some major user-visible changes:
  [bgpd] BGP multipath support has been merged
  [bgpd] SAFI (Multicast topology) support has been extended to
  propagate the topology to zebra.
  [bgpd] AS path limit functionality has been removed
  [babeld] a new routing daemon implementing the BABEL ad-hoc mesh
  routing protocol has been merged.
  [isisd] a major overhaul has been picked up. Please note that
  isisd is STILL NOT SUITABLE FOR PRODUCTION USE.
  [*] a lot of bugs have been fixed, please refer to the git log
  The number of bugfixes and changes in this release is quite large
  at 446 commits, though some commits are counted twice due to a
  merge of Denis
  Ovsienko's RE branch some time ago. (Previous releases had around
  50 commits each.)
- additional changes from 0.99.20.1
  This is a security-fix release that addresses 3 pending CVEs, one
  in bgpd and two in ospfd. The CVEs will be linked once released.
- added quagga-0.99.21_isis_undefined_operations.patch:
  fix compiler warning about undefined operations
- a47c5838e9f445ab887ad927706b11ccbb181364.patch
  Fix typo in isis topology code. Taken from git.
- drop quagga-0.99.20-fix-bgpd-attr-memleak.patch:
  Included upstream
- added options to build tcp-zebra, irdp and pcre:
  all enabled by default
  pcre change might cause problems in edge cases with bgp
  new buildrequires: pcre-devel
- added option to build with isis and isis-topology:
  disabled by default
* Tue Dec  6 2011 olipro@8.c.9.b.0.7.4.0.1.0.0.2.ip6.arpa
- Update package to quagga-0.99.20, remove stale patches.
  added upstream patch to resolve a bgpd memleak
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Sep 19 2011 boyang@suse.com
- DoS while decoding EXTENDED_COMMUNITIES in Quagga's BGP
  [bnc#718062]
* Mon Sep 19 2011 boyang@suse.com
- OSPFD DoS while decoding Link State Update [bnc#718061]
* Mon Sep 19 2011 boyang@suse.com
- OSPFD DoS while decoding Hello packet [bnc#718059]
* Mon Sep 19 2011 boyang@suse.com
- OSPF6D DoS while decoding Database Description packet
  [bnc#718058]
* Mon Sep 19 2011 boyang@suse.com
- OSPF6D buffer overflow while decoding Link State Update with
  Inter Area Prefix Lsa [bnc#718056]
* Thu Jun  2 2011 boyang@novell.com
- Fix bnc#680499, zebro and ripd won't start [bnc#680499]
* Wed Feb 23 2011 prusnak@opensuse.org
- fix CVE-2010-1674 and CVE-2010-1675 [bnc#654270]
* Tue Nov  9 2010 prusnak@opensuse.org
- mark /var/run/quagga as ghost, create it in initscript
  [Fate#303793]
* Tue Nov  9 2010 prusnak@opensuse.org
- updated to 0.99.17 - fixes [bnc#634300]
  bgpd:
    fix handling of AS path data
    tighten bounds checking in RR ORF msg reader
  ospfd:
    Only refresh external default route once.
    Make sure ospf_distribute_list_update_timer() eventually runs.
    Make sure all external routes are updated.
  zebra:
    fix infinite loop when deleting an interface
  ospf6d:
    Fix crash when '[no] ipv6 ospf6 advertise prefix-list' is in startup-config
  isisd:
    change ISIS_METHOD to use C preprocessor
  other:
    build: ignore mkinstalldirs and texinfo.tex
    build: Add QuaggaId to README.NetBSD
    build/extra: Enhance README.NetBSD make/gmake decision.
    git: add pointers to out-of-tree work
    git: add (generated) m4 files to .gitignore
    Update for git and emphasize asking for good reports.
    doc: fixed spelling in bgpd.texi
* Tue Nov  9 2010 prusnak@opensuse.org
- updated to 0.99.16
  bgpd:
    use monotonic clock for time of day
    code cleanup
    compile warnings cleanup
    work around warning in assegments_parse()
  ospfd:
    fix debug messages that were masked by DISCARD_LSA
    remove unneeded memset from a very hot function
    VTY strings cleanup
    comment out unused function
    make local functions static
    enable more OSPF cost command aliases
  lib:
    fix memory logging
    make some structures constant
    move check_bit into prefix common code
    fix warning on little endian
    make match functions take const args
    remove unused function: route_dump_node()
    log source of vty connections (bug #566)
  zebra:
    change router-id selection algo
    deal with irdp compile warnings
    cleanup RIB meta queue code
    fix more warnings in rtadv
    fix more compiler warnings
    remove unused function to fix warning
    handle RTF_CLONING removal from FreeBSD 8.0
    fix argument reference in strncpy() call for BSD
    fix RIB debug message for IPv6
    make declaration const in rtm_flag_dump()
    fix router advertisements for non-Ethernet link layer addresses
  ospf6d:
    remove dead code
    fix warnings from recent prefix bit commit
    review LSA sequence number comparison
    fix LSA locking in ospf6_new_ls_id()
  other:
    ripd: fix compiler warnings
    ripngd: compiler warnings cleanup
    isisd: fix --enable-isis-topology for 64-bit Linux
    isisd: fix BPF ioctl() calls, treat "true" and "false" as reserved
    configure: fix spelling
    configure: fix HAVE_CLOCK_MONOTONIC spelling
* Thu Dec  3 2009 prusnak@suse.cz
- updated to 0.99.15
  * bgpd:
    fix md5 set on listen sockets
    missing pieces from listener patch
    Workaround for invalid MBGP next hop
    Allow inbound connections to non-default view
    fd leak in bgpd
    Delete AS_CONFED_SEQUENCE when prepending an AS_SEQUENCE type segment
    Implement BGP confederation error handling (RFC5065, Par. 5)
    start listener on first instance
    peer action table static/const
    Restore ability of 'neighbor ... update-source' to take interface name
  * ospfd:
    Make sure priority is respected.
    Tighten up the connected check for redistribution
    fix performance problem with redistribute delete
    Make sure route table is recalculated.
    Make "Packet ... received on wrong link" conditional on debug
    Change struct ospf_path *oi to ifindex.
    Discriminate better when selecting links between vertices in SPF
    Make ospf_if_lookup_recv_if() find the right unnumbered i/f
    export ospf_if_table_lookup() and use it in ospf_network_run_interface()
  * ospf6d:
    bug #529, fix endianness problem in earlier commit
  * ripd:
    set IP TOS for control socket
  * zebra:
    do not touch socket before pidfile locking
  * doc:
    zebra.8 via Christian Hammers (#531)
* Wed Aug  5 2009 prusnak@suse.cz
- updated to 0.99.14
  * lib:
    Fix IPv6 normalisation
    Allow for large-file support, e.g. for log files >2GB
  * zebra:
    Silence noisy process_subq
    RFC 4191 Default Router Preference support for router advertisements
    linux policy routing support with ipv6
    Static route does not reach kernel.
  * bgpd:
    Fix nexthop reachability check on confederations
    fix typo made by paul in previous commit
    Avoid zombie accepted peer entries
    Small buffer overrun in bgp_clear_node_queue_init
    Stability fixes including bugs 397, 492
    Fix compiler warnings related to MD5
    Bug #533: Fix crash with copy/pasted commands, inc 'no bgp ...'
    Log a debug/update warning if filters are configured but don't exist
    Add 'show ip bgp view WORD neighbors IP (advertised|received)-routes'
    review 32-bit AS-path hotfix for 0.99.12
    Fix "show ip bgp dampened-paths" garbage output.
    Fixes to RFC2385/MD5 BGP
  * ospfd:
    Do not use stale Network/Router LSAs
    compare ifIndex too when matching paths
    external LSA route_unlock_node() fixes
    Fix a few LSA performance "bugs"
    discount IP header size from a new LSA pkt
    cancel OSPF timer hack in nsm_change_state
  * ospf6d:
    Fix regression in monotonic time patch - LSA max-aging broke
  * vtysh:
    Save vtysh history to a file
    Fix vtysh based "write term" output.
  * doc:
    Add "--disable-doc" to configure
* Wed Jul 15 2009 prusnak@suse.cz
- updated to 0.99.13
  * build:
    [configure] fix check for GNU awk/gawk to abort ./configure if missing
    [configure] add configure support for PCRE Posix library
    [configure] Detect support for monotonic clock
  * zebra:
    [zebra] Force rib_update when connected route deleted
    [zebra] Only announce connected routes if link is detected
    [zebra] MTU is unsigned
    [zebra] remove incorrect debug message
    [zebra] Cleanup meta-queue code
    [zebra] netlink interface minor cleanup
    [zebra] Fix vyatta bug 2814: Add "show ip route summary" command.
  * bgpd:
    [bgpd] Fix 'update-source' command: It doesn't accept interface names
    [bgpd] reference count the BGP instance
    [bgpd] Add support for the old Linux 2.4, TCP_MD5_AUTH RFC2385 patch
    [bgpd] Fixed as-path prepend/exclude ASN handling
    [bgp] Fix crash on SIGHUP, deref of freed workqueues
    [bgpd] 64-bit bugfix in community_del_val
  * ospfd:
    [ospfd] Fix OSPF route refcount leak
    [ospfd] fix vty ospfd no ospf abr-type standard
  * ospf6d:
    Convert ospf6d over to quagga_gettime() wrappers.
    [ospf6d] Remove 'no router' from OSPF6_NODE
    [ospf6d] Fix ospf6d crash if removing interface with no area
    [ospf6d] Fix ospf6d crash in show border routers
    [ospf6] Add no router ospf6
    [ospf6d] Fix ospf6d crash if range defined twice
  * ripd:
    [ripd] Ignore non-running interfaces in rip status
    [ripd] Fix metrix in call to rip_zebra_ipv4_delete
  * vtysh:
    [vtysh] Add a --noerror option
    [vtysh] Return non-zero exit code on error.
    [vtysh] Make vtysh more useable for scripting
    [vtysh] Force line buffered mode.
  * misc:
    [daemons/cleanup] Remove disabled log_mode argument support.
    [lib] Put symbolic backtrace on system log
    [lib] sockopt_tcp_signature: sin6 requires HAVE_IPV6
    [smux] 64-bit fix for lib/smux.h SNMP_INTEGER() macro
* Wed May 13 2009 prusnak@suse.cz
- updated to 0.99.12
  * bgpd:
    Fix bgp ipv4/ipv6 accept handling
    [bgpd] AS4 bugfix by Chris Caputo
    [bgpd] Add 'show bgp views' command
    [bgpd] Allow accepted peers to progress even if realpeer is in Connect
  * ospfd:
    [lib] Move type cast in Fletcher checksum
    [lib] Switch Fletcher checksum back to old ospfd version
    Justified OSPF cost function names and added support for:
    ospf cost <1-65535> A.B.C.D
    no ospf cost <1-65535>
  * library:
    [lib] Fix timer precision.
    [lib] fix missing sockunion_normalise_mapped
  * vtysh:
    [vtysh] Add commands from zebra_routemap.c to vtysh
  * misc:
    [build] tools/multiple-bgpd.sh should be in 'make dist'
- added logrotate to Recommends
- removed obsoleted patches:
  * bgpd-asn-dos.patch (mainline)
* Thu May  7 2009 prusnak@suse.cz
- fixed crash (DoS) in BGP daemon via an ASN elements
  (bgpd-asn-dos.patch) [bnc#500540]
* Mon Jan 19 2009 prusnak@suse.cz
- updated to 0.99.11
  * bgpd:
  - Document the FSM dummy-peer race that sometimes afflicts
    session setup
  - Fix definition of an rsclient command
  - Fix double-free crash in bgp_table_finish, seen with rs-client
  - Fix triggerable crash when compiled with --disable-bgp-announce
  - TCP-MD5: password vty configuration and initial Linux support
  * isisd:
  - Try open vanity-named DLPI dev before style 1,2
  - Fix packet filtering with DLPI
  - Switch to lib/ Fletcher checksum, fixing bug in isisd
  * lib:
  - Add fletcher checksum implementation
  - Add support for a 'restricted mode' with anonymous vty
    connections
  - Allow delete during password entry
  - CMD_AS_RANGE accidently quoted and so not expanded in vty
  * ospfd:
  - Default route needs to be refreshed after neighbour state change
  - Fix SEGV during startup introduced in recent commit
  - Move passive interface check
  - Restructure opsf_if_update() and ospf_network_run()
  - Fix SEGV in ip ospf neighbor all
  - Ignore host routes to self.
  - Set destination for PtP links to OSPF_ALLSPFROUTERS
  * zebra:
  - Filter out unwanted netlink messages by PID
  - clean up blocking setting of netlink sockets
  - netlink buffer size tweaking only needed on receive socket
  - netlink: no need to change privs for receive
  - netlink: quiet harmless errors
  - Set proto/scope on all route update messages
  - Make BSD link-state deal more gracefully with GIFMEDIA ioctl
    error
  - ignore dead routes in RIB update
* Fri Sep 12 2008 crrodriguez@suse.de
- disable static libraries
* Thu Aug 28 2008 cthiel@suse.de
- fix init scripts
* Mon Jul 28 2008 prusnak@suse.cz
- updated to 0.99.10
  * [bgpd] 4-byte AS support added
  * [bgpd] MRT format changes to version 2.
    Those relying on bgpd MRT table dumps may need to update their tools.
  * [bgpd] Added new route-map set statement: "as-path exclude"
  * Zebra RIB updates queue has evolved into a multi-level structure
    to address RIB consistency issues.
- removed obsoleted patch:
  * badshift.patch (included in update)
* Tue Jan  8 2008 prusnak@suse.cz
- fixed bad left shift (badshift.patch) [#351517]
* Tue Sep 25 2007 prusnak@suse.cz
- updated to 0.99.9
  * added support for separate link-layer access mechanisms in isisd
  * add back check for inet_aton, which got dropped somehow
    in previous jumbo patch
  * use AC_GNU_SOURCE to define _GNU_SOURCE, rather than having
    lib/zebra.h do it
  * AC_FUNC_STRNLEN has side-effects with latest autoconf,
    use AC_CHECK_FUNC on strnlen instead
  * general cleanup of header and type checks, introducing an internal
    define, QUAGGA_INCLUDES, to build up a list of stuff to include so
    as to avoid 'present but cant be compiled' warnings
  * misc additional checks of things missing according to autoscan
  * add LIBM, for bgpd's use of libm, so as to avoid burdening LIBS,
    and all the binaries, with libm linkage
  * remove the bad practice of using m4 changequote(),
    just quote the []'s in the case statements properly
  * update all HAVE_* to the standard autoconf namespaced HAVE_* defines
    (i.e. HAVE_SA_LEN->HAVE_STRUCT_SOCKADDR_SA_LEN)
  * add LIBM to bgpd's LDADD, for pow()
  * change gcc CFLAGS from '-std=c99' to '-std=gnu99' to improve
    portability
- dropped obsolete patches:
  * strcmp.patch (included in update)
* Thu Sep 13 2007 prusnak@suse.cz
- backported security fixes for bgpd from 0.99.9 [#310166]
* Thu Jun  7 2007 prusnak@suse.cz
- removed broken strict-aliasing.patch
- added -fno-strict-aliasing to CFLAGS
* Wed Jun  6 2007 prusnak@suse.cz
- updated to 0.99.7
- added mandatory LSB tags Short-Description to init files
- added %%run_ldconfig to %%post and %%postun sections
- cleaned spec file
- dropped obsolete patches:
  * CVE-2007-1995.patch (included in update)
* Tue Apr 24 2007 anosek@suse.cz
- updated to version 0.99.6
  * bgpd
    o Bug #302, bgpd can get stuck in state Clearing
    o Implement 'debug bgp zebra' to log all messages to and from zebra.
    o Fix bug where a deleted route that was quickly re-added was being lost
    o trivial: non C99 u_int.._t should be uint.._t
    o struct peer must have bgp field valid (redistribute crash)
    o Coverity CID #64: Needless NULL check, CID #64: Deref of potentially NULL pointer.
    o CID#73, potential crash in bgp statistics if called for AFI/SAFI with emtpy table
    o Bug #302 fixes. ClearingCompleted event gets flushed, leaving peers stuck in Clearing.
    o Trivial fix of printf format/arg mismatch
    o reduce the process queue hold time to something more sensible
    o RIB statistics address space size shouldnt double count space
    o simplify peer refcounts, squash slow peer leak
    o Fix 0.99 shutdown regression, introduce Clearing and Deleted states
    o Add RIB reporting commands, show bgp ... statistics
    o Handle pcount as flags are changed, fixing pcount issues
    o Add 'show ... neighbor .... prefix-counts' command
  * ospfd
    o Consider all connected addresses when creating ospf interfaces
    o Add debug messages for a few zebra messages that had been overlooked
    o Fix bug in passive-interface default commands.
    o Stop losing subsequent default-information originate 'always' info
    o Add passive-interface default support
    o Improve some warning messages.
    o Fix assertion in DB-exchange fix, hit by ogier-db-ex-opt commit
  * isisd: Fix compiler warnings and allow v4-only compilation
  * zebra
    o Changes of nexthops of static routes didnt take effect
    o Compile fix for PF_ROUTE
  * ripd
    o bug #293: routemap set metric doesn't check for underflow correctly
    o bug #278: remove gratuitous use of mid-function declaration
  * general
    o [daemon startup] Add --dry-run/-C argument to daemons, to check config file syntax
    o Handle upgrade from SUNWzebra to Quagga for 'interface fooX:Y' commands
    o [snmp] Fix asn_build calls to pass correct variable sizes (fixes 64-bit issues)
    o [doc] Add recent NetBSD/FreeBSD versions to list of what ought to work.
- dropped obsolete patches snmp.diff, nextnode.diff
- fixed VUL-0: quagga DoS [#266100] (CVE-2007-1995.patch)
* Tue Jan 23 2007 prusnak@suse.cz
- fixed insufficient strcmp.diff
* Wed Dec 20 2006 prusnak@suse.cz
- fixed "nextnode" misuse
* Tue Dec 19 2006 prusnak@suse.cz
- fixed "comparison with string literal" [#228420]
* Mon Aug 21 2006 kukuk@suse.de
- Fix PAM config to work on lib64 archs.
* Thu Aug  3 2006 mmarek@suse.cz
- updated to version 0.98.6
  * comtains latest security fixes, obsoleting CVE-2006-2223-4.patch
  * some ospfd bugfixes
- dropped netlink-fix.diff, which has been obsolete for some time
* Fri Jun 16 2006 schwab@suse.de
- Remove old and broken libtool macros.
* Fri May 12 2006 mmarek@suse.cz
- fixed ripd not configurable to protect routing table from
  malicious updates (CVE-2006-2223, CVE-2006-2224)
  [#173828] (CVE-2006-2223-4.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 mmarek@suse.cz
- use $RPM_OPT_FLAGS (missing backslash)
- check for /proc/net/{dev,route,snmp} before build
* Tue Nov 22 2005 mmarek@suse.cz
- don't try to create fake directories under /proc (we don't build
  as root since Fri Jan 16 13:23:46 CET 2004), but print an error
  instead.
* Tue Oct 11 2005 mmarek@suse.cz
- better strict aliasing fix
* Mon Oct 10 2005 mmarek@suse.cz
- update to 0.98.5
* Tue Sep 20 2005 mmarek@suse.cz
- fixx gcc warnings
* Mon Aug  1 2005 anicka@suse.cz
- update to 0.98.4
* Tue Apr 19 2005 postadal@suse.de
- updated to version 0.98.3
- removed obsoleted patch config.diff
- use parallel make
* Thu Jan 13 2005 postadal@suse.cz
- updated to version 0.98.0
  * some commands may have been removed or have had their syntax changed
- removed obsoleted patch gcc-warnings-fix.diff
* Fri Nov 26 2004 postadal@suse.cz
- fixed lib64 path
* Thu Nov 25 2004 postadal@suse.cz
- updated to version 0.97.3
- fixed gcc warnings
- created subpackage "quagga-devel"
* Wed Aug 11 2004 postadal@suse.cz
- updated to version 0.96.5
* Thu Jun 17 2004 postadal@suse.cz
- enabled multipath for High Availability scenario [#41789]
* Wed Feb 11 2004 postadal@suse.cz
- updated to version 0.96.4
- fixed instalation problems [#33015]
- added quagga user/group
- removed obsoleted patch vty_telnet_option-fix
* Mon Jan 19 2004 postadal@suse.cz
- fixed security bug [#33993] (CAN-2003-0858): local users could send malicious
  netlink messages that cause DoS condition
- fixed DoS condition, which exists in zebra when layer 3 access is possible
  to the telnet management port 2601/tcp. (CAN-2003-0795) [#32656]
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
- Build as user
* Mon Nov 10 2003 ro@suse.de
- use net-snmp instead of ucdsnmp
* Fri Nov  7 2003 postadal@suse.cz
- fixed DoS condition, which exists in zebra when layer 3 access is possible
  to the telnet management port 2601/tcp. (CAN-2003-0795) [#32656]
* Tue Aug 26 2003 postadal@suse.cz
- updated to bugfix version 0.96.2
  * fixed a small but very annoying ospfd bug
  * command.c newline fix
* Mon Aug 25 2003 postadal@suse.cz
- Zebra-pj has now forked from GNU Zebra. The new name is Quagga.
- update to version 0.96.1
- use new stop_on_removal/restart_on_upate macros
* Mon Jul 28 2003 postadal@suse.cz
- fixed ripngd init script [#27097]
* Fri Jul 25 2003 mludvig@suse.cz
- Update to Paul Jakma's Zebra fork. This is the only
  Zebra version currently maintained.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Wed Feb 12 2003 mmj@suse.de
- Use %%install_info macro [#23478]
* Wed Nov 27 2002 postadal@suse.cz
- added kame-fix patch of mludvig@suse.cz
- bzipped source and rc.* moved to rc.tar.bz2 (init/SuSE/*)
* Thu Sep 26 2002 mludvig@suse.cz
- Upgrade to zebra-0.93b
- Added pam script
* Fri Aug 16 2002 postadal@suse.cz
- added %%insserv_prereq and %%fillup_prereq to PreReq [#18024]
* Sat Jul 27 2002 adrian@suse.de
- do not source rc.config
* Wed May 15 2002 schwab@suse.de
- Use autoreconf.
* Mon Feb 25 2002 postadal@suse.cz
- modified copyright of files in /etc/init.d
* Thu Jan 10 2002 egmont@suselinux.hu
- changed /sbin/init.d to /etc/init.d in init script comments
* Tue Dec 11 2001 cihlar@suse.cz
- removed START_* variables
- fixed init scripts to fit skeleton
- fixed file list
* Tue Nov  6 2001 cihlar@suse.cz
- fixed to compile with automake 1.5
* Mon Aug 27 2001 dan@suse.cz
- update to 0.92a release
  * Fix community-list "^$" matching bug
  * -lsnmp check problem fixed
- build root added, spec file clean-up
- installing info pages fixed
* Tue Aug 14 2001 ro@suse.de
- up to 0.91a and fixed for current autoconf
* Mon May 14 2001 lmuelle@suse.de
- fix typo in ripd startscript
- bzip2 sources
* Tue May  8 2001 strbac@suse.de
- remove init scripts and symlinks for vtysh (it's not a daemon)
* Thu Feb 22 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Wed Jan 17 2001 bk@suse.de
- updated to 0.90a, fixes serious bug of bgpd when receiving routes
- fixed a bug in configure(.in) to detect *-suse-linux as linux
- replaced ipv6 configure diff with the configure option --enable-ipv6
- call autoconf to generate the fixed confgure (never patch configure)
- set CFLAGS to RPM_OPT_FLAGS for configure
- folded up configure argument list to make it more readable
* Thu Jan 11 2001 smueller@suse.de
- make it compile with IPv6 even if there is no IPv6 in the
  running kernel
* Thu Jan 11 2001 smueller@suse.de
- update to zebra 0.90
- enabled snmp support
* Thu Dec 21 2000 smueller@suse.de
- rc.config injection corrected
* Wed Dec 20 2000 smueller@suse.de
- changed absolut path names to relative in %%post
* Tue Dec  5 2000 bjacke@suse.de
- bzipped sources
- cleaned up spec file
- enabled IPv6 support
* Mon Dec  4 2000 smueller@suse.de
- initial version for 7.1
